@@ -50,6 +50,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import BatchServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import BatchServiceGrpcTransport
 from .transports.grpc_asyncio import BatchServiceGrpcAsyncIOTransport
+from .transports.rest import BatchServiceRestTransport
 
 
 class BatchServiceClientMeta(type):
@@ -63,6 +64,7 @@ class BatchServiceClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[BatchServiceTransport]]
     _transport_registry["grpc"] = BatchServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = BatchServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = BatchServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -409,6 +411,9 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
             transport (Union[str, BatchServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -504,6 +509,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_create_job():
@@ -621,6 +633,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_get_job():
@@ -711,6 +730,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_delete_job():
@@ -824,6 +850,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_list_jobs():
@@ -927,6 +960,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_get_task():
@@ -1017,6 +1057,13 @@ class BatchServiceClient(metaclass=BatchServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import batch_v1alpha
 
             def sample_list_tasks():
